#
# spec file for package gobby
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gobby
%define _versioned_name gobby-0.5
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gnome-doc-utils-devel
BuildRequires:  intltool
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glibmm-2.4)
%if 0%{?favor_gtk2}
BuildRequires:  pkgconfig(gtkmm-2.4)
BuildRequires:  pkgconfig(gtksourceview-2.0)
%else
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  pkgconfig(gtksourceview-3.0)
%endif
BuildRequires:  pkgconfig(libgsasl)
BuildRequires:  pkgconfig(libinfinity-0.6)
BuildRequires:  pkgconfig(libxml++-2.6)
BuildRequires:  pkgconfig(unique-1.0)
# For directory ownership:
BuildRequires:  gnome-themes
Version:        0.5.0
Release:        2.4
Summary:        Gobby collaborative editor (Infinote protocol)
License:        GPL-2.0+
Group:          Productivity/Editors/Other
Source:         %{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gobby-add-missing-return.patch zaitor@opensuse.org -- Add a missing return statement
Patch0:         gobby-add-missing-return.patch
Url:            http://gobby.0x539.de/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(post): update-alternatives
Requires(postun): update-alternatives
# The build service fails to build the package because it doesn't really
# understand Requires(post), so use PreReq too (see bnc#439232).
%if %defined suse_version
PreReq:         update-alternatives
%endif
Recommends:     %{name}-lang

%description
Gobby is a free collaborative editor. This means that it provides you
with the possibility to edit files simultaneously with other users over
a network. It supports multiple documents in one session.
The platforms on which you could use Gobby are so far Microsoft Windows,
Linux, Mac OS X and other Unix-like ones.

This is the latest version of Gobby, which is using the Infinote protocol.

%lang_package
%prep
%setup -q
%patch0 -p1

%build
%configure \
    --disable-scrollkeeper \
    --with-gnome \
%if 0%{?favor_gtk2}
    --without-gtk3
%else
    --with-gtk3
%endif
%{__make} %{?jobs:-j%jobs}

%install
%makeinstall
%find_lang gobby05 %{?no_lang_C}
# For documentation. It's not versioned, but gobby 0.4 doesn't have such files,
# so there's no conflict.
%find_lang gobby %{?no_lang_C} gobby05.lang
%suse_update_desktop_file -N "Gobby" -G "Collaborative Editor" %{_versioned_name} X-SuSE-Core-Internet
%fdupes %{buildroot}

%clean
rm -rf %{buildroot}

%post
# If the %{name} group is in automatic mode, then this will also switch all
# symlinks automatically
update-alternatives --install %{_bindir}/%{name} %{name} %{_bindir}/%{name}-0.5 5 --slave %{_mandir}/man1/%{name}.1.gz %{name}.1.gz %{_mandir}/man1/%{name}-0.5.1.gz
%if 0%{?suse_version} > 1130
%desktop_database_post
%icon_theme_cache_post
%icon_theme_cache_post HighContrastLargePrint
%icon_theme_cache_post HighContrastLargePrintInverse
%endif

%postun
# Note: we don't use "$1 -eq 0", to avoid issues if the package gets renamed
if [ ! -f %{_bindir}/%{name}-0.5 ]; then
  update-alternatives --remove %{name} %{_bindir}/%{name}-0.5
fi
%if 0%{?suse_version} > 1130
%desktop_database_postun
%icon_theme_cache_postun
%icon_theme_cache_postun HighContrastLargePrint
%icon_theme_cache_postun HighContrastLargePrintInverse
%endif

%posttrans
# Workaround old bug in 11.1/11.2 packages that always removed the symlinks in
# %postun. Can be removed during 12.2 development.
if [ ! -f %{_bindir}/%{name} -a -f %{_bindir}/%{name}-0.5 ]; then
  update-alternatives --install %{_bindir}/%{name} %{name} %{_bindir}/%{name}-0.5 5 --slave %{_mandir}/man1/%{name}.1.gz %{name}.1.gz %{_mandir}/man1/%{name}-0.5.1.gz
fi

%files
%defattr (-, root, root)
%doc AUTHORS COPYING ChangeLog NEWS
%dir %{_datadir}/gnome/
%dir %{_datadir}/gnome/help/
%dir %{_datadir}/gnome/help/%{name}/
%doc %{_datadir}/gnome/help/%{name}/C/
%dir %{_datadir}/omf/
%dir %{_datadir}/omf/%{name}/
%doc %{_datadir}/omf/%{name}/%{name}-C.omf
%{_bindir}/%{_versioned_name}
%{_datadir}/%{_versioned_name}
%{_datadir}/applications/%{_versioned_name}.desktop
%{_datadir}/icons/*/*/apps/%{_versioned_name}.*
%doc %{_mandir}/man1/*.*
%dir %{_datadir}/appdata/
%{_datadir}/appdata/gobby-0.5.appdata.xml
# FIXME: gnome-themes does not provide excluded directories yet.
%exclude %{_datadir}/icons/HighContrast*/scalable/*

%files lang -f gobby05.lang

%changelog
* Sat Oct 11 2014 zaitor@opensuse.org
- Update to version 0.5.0:
  + Allow to run a server within the Gobby process; infinoted is no
    longer required to connect to other people.
  + Added support for user accounts and different permissions for
    different accounts.
  + Added limited support for chat nodes in the document tree.
  + Added an option to set the opacity with which user colors are
    shown behind the text.
  + Added Fullscreen option and Ctrl++ and Ctrl+- shortcuts to
    increase/decrease the font size.
  + Gobby can open infinote://XXX URIs given on the command line to
    directly open one or more documents at startup.
- Replace pkgconfig(libinfinity-0.5) for pkgconfig(libinfinity-0.6)
  following upstream changes.
- Drop gobby-glibmm-2_31.patch and gobby-gtksourceview38.patch:
  Fixed upstream.
- Add gobby-add-missing-return.patch: Fix a missing return.
* Fri Apr 19 2013 dimstar@opensuse.org
- Add gobby-gtksourceview38.patch: Fix build with gtksourceview 3.8
  that changed to single header includes.
* Tue Apr  9 2013 cfarrell@suse.com
- license update: GPL-2.0+
  No indication of GPL-2.0 "only" code and certainly no indication of
  aggregation
* Sat Mar  2 2013 coolo@suse.com
- update license to new format
* Thu Feb  9 2012 dimstar@opensuse.org
- Add gobby-glibmm-2_31.patch: Fix build with glibmm 2.31.
* Fri May 27 2011 vuntz@opensuse.org
- Move to pkgconfig()-style BuildRequires:
  + Old ones: glibmm2-devel, gtkmm2-devel, libinfinity-devel,
    libunique-devel, libxml++-devel.
  + New ones: glibmm-2.4, gtkmm-2.4, libgsasl, libinfinity-0.5,
    libxml++-2.6, unique-1.0.
* Thu Apr 28 2011 dimstar@opensuse.org
- Use favor_gtk2 to switch between gtk2 and gtk3 builds.
- For gtk3 build, add pkgconfig(gtkmm-3.0) and
  pkgconfig(gtksourceview-3.0) BuildRequires.
- Pass -with-gtk3/--without-gtk3 based on favor_gtk2 to configure.
* Tue Apr 26 2011 dimstar@opensuse.org
- Update to version 0.4.94:
  + Show cursors and selections of remote users in the own viewport
    and scrollbar
  + Add a "Disconnect from Server" option to the context menu
  + When double-clicking a user in the user list jump to its
    current cursor position
  + Allow gobby to be built against GTK+ 3
  + Fixed a bug which prevented "Save All" from working.
- Replace gtksourceview-devel BuildRequires with
  pkgconfig(gtksourceview-2.0).
- Drop gobby-fix-finddialog-voidreturn.patch: fixed upstream.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Dec 14 2010 vuntz@opensuse.org
- Own /usr/share/gnome and /usr/share/gnome/help to fix build.
* Wed Oct 13 2010 vuntz@opensuse.org
- Do not add wrong categories to gobby.desktop (Office,
  X-SuSE-Core-Office). Add X-SuSE-Core-Internet to make the build
  happy, though.
* Sun Dec 20 2009 vuntz@opensuse.org
- Update to version 0.4.93:
  + Added IRC-like chat
  + Added functionality to export a document to HTML
  + Sort browser entries
  + Allow selecting multiple files when opening files
  + Allow resetting user colors in a document
  + Added a Connect to Server option to the File menu
  + Undo words instead of individual characters
  + When starting Gobby twice then send commands to an existing
    Gobby (if any) unless the -n command line option is given
  + Added an option to highlight spaces and tabs
- Drop gobby-desktop.patch: fixed upstream.
- Add gnome-doc-utils-devel and libunique-devel BuildRequires.
- Pass --disable-scrollkeeper to configure.
* Mon Dec  7 2009 vuntz@opensuse.org
- Rework the update-alternatives part to be correctly handle
  package upgrades. Note that we need a %%posttrans to work around
  bugs in previously installed packages.
* Wed Aug 19 2009 beineri@opensuse.org
- don't put version number into Name field of .desktop file of
  current version but older version (gobby4 package)
* Sat Jun 13 2009 vuntz@novell.com
- Clean up file list.
- Update gobby-desktop.patch: do not change Name, GenericName,
  Categories there, but with suse_update_desktop_file.
- Remove unneeded BuildRequires: gmp-devel, gnutls-devel,
  libavahi-glib-devel, libglade2-devel, libgnomeprintui-devel,
  libgnomeui-devel, libwnck-devel, libgsasl-devel.
- Remove AutoReqProv: it's default now.
- Add update-alternatives PreReq.and use update-alternatives to
  have non-versioned filenames.
* Thu Apr 30 2009 novell@mirell.de
- Update to version 0.4.92:
  * Support running Gobby on Windows 2000.
  * Added Icons for HCLP and HCLPI icon themes (Bug #413, Patrick Wade).
  * Make sure terminating newline characters are saved correctly
  * Added /etc/ssl/certs/ca-certificates.crt as default trust file, if
    available.
  * Don't mess up saving documents whose first line is empty.
  * Write config files in $XDG_CONFIG_HOME instead of $HOME (Bug #437,
    Cristian Klein).
  * Display colored pencil icons in a document's tab for each user that
    made a change since the document has been viewed the last time
    (Bug #66, Mattis Manzel).
* Fri Feb  6 2009 novell@mirell.de
- Update to version 0.4.91:
  + Keep track of a document's modified state between Undo/Redo
  operations
  + Scroll to Cursor after Cut or Paste
  + Added HCLPI icon of the Gobby Logo (Thanks to Thomas Glatt)
  + Added an Autosave Option in the preferences
  + Remember previous host names in "Direct Connection" entry
  + Added an "Open Location" dialog to open arbitrary URIs
  + Added a tooltip when hovering text, showing the author of that text
- Update to version 0.4.90:
  + Complete rewrite
  + Discards net6 and obby, uses libinfinity now
- Rebase gobby-desktop.patch.
- Add gobby-fix-finddialog-voidreturn.patch.
* Sun Jan 25 2009 vuntz@novell.com
- Sanitize BuildRequires.
- Use %%exclude instead of rm for icon files that we can't use at
  the moment.
* Fri Jan  2 2009 msuman@suse.de
- Update to version 0.4.9:
  + Some fixes improving Gobby's accessibility.
  + Use UTF-8 encoded filenames.
  + Updated translations, translation fixes.
- Re-based gobby-desktop.patch
* Thu Jan  1 2009 msuman@suse.de
- Update to version 0.4.8:
  + Fixes a crash when trying to join sessions withouth the avahi
    daemon being running.
- Dropped this patch:
  + gobby-0.4.4-gcc-43.patch - no longer required.
* Fri Sep 12 2008 maw@suse.de
- Update to version 0.4.7:
  + Some fixes improving Gobby's accessibility
  + Enable IPv6 link-local Zeroconf support
  + Bugfixes:
  * Do not crash when no GtkSourceView languages are installed
  * Do not show hidden GtkSourceView languages to the user as
    they are not supposed to be shown and could lead to crashes
  + Updated translations.
* Thu Apr  3 2008 maw@suse.de
- Require obby >= 0.4.5, not 0.4.6.
* Wed Apr  2 2008 maw@suse.de
- Update to version 0.4.6:
  + Bug fixes
  + Updated translations.
* Thu Nov  8 2007 mauro@suse.de
- Added some fixes for gcc 4.3 and beta.
* Thu Oct 11 2007 sbrabec@suse.cz
- Use binding specific avahi package.
* Mon Sep  3 2007 maw@suse.de
- Build against gtksourceview 1.8 again.
* Tue Aug  7 2007 maw@suse.de
- Split off a -lang subpackage.
* Fri Aug  3 2007 maw@suse.de
- Update to versino 0.4.4:
  + opens absolute file names passed via command line
  + view is kept when remote ops affect the current position
  + documents can be subscribed by doubleclicking on them in the
    list
  + local files aren't flagged as modified
  + urgency hint is configurable
  + tab bar only shown when more than one doc is being edited
  + find and goto dialogs are focused on invocation
  + prefence option added to subscribe automagically to all docs
    in a session
  + window highlights itself only if the chat window is open
  + zeroconf failures are only printed in the console, not in a
    dialog
  + use GtkSourceView's C API directly
  + document list is now sorted alphabetically
  + Misc. fixes
  + Updated translations
- Build against gtksourceview2
- Add gtksourceview.patch
- Use %%fdupes.
* Thu Jun  7 2007 sbrabec@suse.cz
- Fixed desktop file translation.
- Removed invalid desktop Category "Application" (#254654).
* Tue Jan 30 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Tue Sep 26 2006 wstephenson@suse.de
- Update to version 0.4.1
  * Support encrypted communications
  * Improve text handling
  * Improve change merging algorithm
  * Usability improvements
  * Command subsystem eg /command
* Fri Sep 15 2006 jhargadon@suse.de
- update to version 0.3.1
- Bugfix release to correct a problem regarding copy'n'paste
- applied a patch to eliminate missing return statement warnings
  for bug #203564
* Tue Sep  5 2006 meissner@suse.de
- build with CXXFLAGS=RPM_OPT_FLAGS.
* Sat Feb 18 2006 stbinner@suse.de
- fix gobby-desktop.patch (Name / GenericName)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 lmichnovic@suse.cz
- Update to version 0.3.0 [#144674]
* Wed Jan 18 2006 lmichnovic@suse.cz
- Updated to version 0.3.0rc3
* Sat Jan 14 2006 kukuk@suse.de
- Add gmp-devel to nfb
* Fri Nov  4 2005 gekker@suse.de
- Initial import into autobuild, version 0.2.2
